@@ -69,6 +69,7 @@ func init() {
 		"man-summary":           "Outputs a man page summary of a command",
 		"map":                   "Creates a map from two data sources",
 		"match":                 "Match an exact value in an array",
+		"method":                "Define a methods supported data-types",
 		"msort":                 "Sorts an array - data type agnostic",
 		"mtac":                  "Reverse the order of an array",
 		"murex-docs":            "Displays the man pages for _murex_ builtins",
@@ -205,6 +206,7 @@ func init() {
 		"map":                   "map",
 		"match":                 "match",
 		"!match":                "match",
+		"method":                "method",
 		"msort":                 "msort",
 		"mtac":                  "mtac",
 		"murex-docs":            "murex-docs",
