@@ -2,10 +2,8 @@ package shell
 
 import (
 	"fmt"
-	"os"
 	"strings"
 
-	"github.com/lmorg/murex/builtins/docs"
 	"github.com/lmorg/murex/debug"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/types"
@@ -15,16 +13,10 @@ import (
 	"github.com/lmorg/murex/shell/variables"
 	"github.com/lmorg/murex/utils"
 	"github.com/lmorg/murex/utils/ansi"
-	"github.com/lmorg/murex/utils/escape"
-	"github.com/lmorg/murex/utils/man"
-	"github.com/lmorg/murex/utils/which"
+	"github.com/lmorg/murex/utils/parser"
 )
 
 var (
-	// Summary is an overriding summary for readline hints
-	Summary = hintsummary.New()
-
-	manDesc        = make(map[string]string)
 	cachedHintText []rune
 )
 
@@ -34,9 +26,9 @@ func hintText(line []rune, pos int) []rune {
 		return r
 	}
 
-	pt, _ := parse(line)
+	pt, _ := parser.Parse(line, 0)
 	cmd := pt.FuncName
-	var summary string
+	//var summary string
 
 	/*if pt.ExpectFunc == false {
 		// autocomplete hint
@@ -48,69 +40,15 @@ func hintText(line []rune, pos int) []rune {
 	}
 
 	// check if a custom summary has been set
-	custom := Summary.Get(cmd)
-	if custom != "" {
-		summary = custom
-	}
+	r = hintsummary.Get(cmd, autocomplete.GlobalExes[cmd])
 
-	if lang.GlobalAliases.Exists(cmd) {
-		a := lang.GlobalAliases.Get(cmd)
-		alias := make([]string, len(a))
-		copy(alias, a)
-		escape.CommandLine(alias)
-		s := strings.Join(alias, " ")
-		r = []rune("(alias) " + s + " => ")
-		cmd = alias[0]
-	}
-
-	if lang.MxFunctions.Exists(cmd) {
-		if summary == "" {
-			summary, _ = lang.MxFunctions.Summary(cmd)
-		}
-
-		if summary == "" {
-			summary = "no summary written"
-		}
-		return append(r, []rune("(murex function) "+summary)...)
-	}
-
-	if lang.GoFunctions[cmd] != nil {
-		if summary == "" {
-			synonym := docs.Synonym[cmd]
-			summary = docs.Summary[synonym]
-		}
-
-		if summary == "" {
-			summary = "no doc written"
-		}
-		r = append(r, []rune("(builtin) "+summary)...)
-		return r
-	}
-
-	if autocomplete.GlobalExes[cmd] {
-		if summary == "" {
-			summary = manDesc[cmd]
-		}
-
-		if summary == "" {
-			summary = man.ParseSummary(man.GetManPages(cmd))
-		}
-
-		if summary == "" {
-			summary = "no man page found"
-		}
-
-		manDesc[cmd] = summary
-		w := readlink(which.Which(cmd))
-
-		r = append(r, []rune("("+w+") "+summary)...)
-		if len(r) > 0 {
-			return r
-		}
+	if pt.ExpectParam && len(r) == 0 {
+		r = append(r, []rune(
+			fmt.Sprintf("%starget `"+cmd+"` was not found%s", ansi.FgRed, ansi.Reset),
+		)...)
 	}
 
 	if len(r) > 0 {
-		r = append(r, []rune("target `"+cmd+"` was not found")...)
 		return r
 	}
 
@@ -143,26 +81,6 @@ func hintExpandVariables(line []rune) []rune {
 	return []rune{}
 }
 
-func readlink(path string) string {
-	/*f, err := os.Stat(path)
-	if err != nil {
-		return err.Error()
-	}
-
-	if f.Mode()&os.ModeSymlink != 0 {
-		return path
-	}*/
-
-	ln, err := os.Readlink(path)
-	if err != nil {
-		return path
-	}
-
-	//if ln[0] != consts.PathSlash[0] {
-	return ln //path + " => " + ln
-	//}
-}
-
 func hintCodeBlock() []rune {
 	if len(cachedHintText) > 0 {
 		return cachedHintText
